<?php
/**
 * Watson_Driver:: defines an API for implementing storage backends for
 * Watson.
 *
 * $Horde: watson/lib/Driver.php,v 1.15 2007/02/21 10:25:28 jan Exp $
 *
 * Copyright 2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Jan Zagar <jan.zagar@siol.net>
 * @package Watson
 */
class Watson_Driver {

    /**
     * Attempts to return a concrete Watson_Driver instance based on $driver.
     *
     * @param string $driver  The type of the concrete Watson_Driver subclass
     *                        to return.  The class name is based on the
     *                        storage driver ($driver).  The code is
     *                        dynamically included.
     *
     * @param array $params   A hash containing any additional configuration
     *                        or connection parameters a subclass might need.
     *
     * @return Watson_Driver  The newly created concrete Watson_Driver
     *                          instance, or false on an error.
     */
    function factory($driver = null, $params = null)
    {
        if ($driver === null) {
            $driver = $GLOBALS['conf']['storage']['driver'];
        }
        $driver = basename($driver);

        if ($params === null) {
            $params = Horde::getDriverConfig('storage', $driver);
        }

        $class = 'Watson_Driver_' . $driver;
        if (!class_exists($class)) {
            include dirname(__FILE__) . '/Driver/' . $driver . '.php';
        }
        if (class_exists($class)) {
            return new $class($params);
        } else {
            return false;
        }
    }

}
