<?php
/**
 * $Horde: jonah/content_edit.php,v 1.8 2007/06/27 17:23:48 jan Exp $
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 *
 * @author Jan Zagar <jan.zagar@siol.net>
 */
@define('WATSON_BASE', dirname(__FILE__));
require_once WATSON_BASE . '/lib/base.php';
require_once WATSON_BASE . '/config/sources.php';

$title = _("TV Table");

if (($channels = Util::getFormData('display_chan')) !== null) {
    $prefs->setValue('display_chan', serialize($channels));
} else {
    $channels = unserialize($prefs->getValue('display_chan'));
    if (empty($channels)) {
        $channels = array();
    }
}

$numChannels = count($channels);

require_once 'Horde/Variables.php';
require_once 'Horde/UI/Tabs.php';

$tabs = new Horde_UI_Tabs('time', Variables::getDefaultVariables());
$tabs->addTab('5:00 - 8:00', Horde::applicationUrl('now.php'), '5');
$tabs->addTab('8:00 - 11:00', Horde::applicationUrl('now.php'), '8');
$tabs->addTab('11:00 - 14:00', Horde::applicationUrl('now.php'), '11');
$tabs->addTab('14:00 - 17:00', Horde::applicationUrl('now.php'), '14');
$tabs->addTab('17:00 - 20:00', Horde::applicationUrl('now.php'), '17');
$tabs->addTab('20:00 - 23:00', Horde::applicationUrl('now.php'), '20');
$tabs->addTab('23:00 - 2:00', Horde::applicationUrl('now.php'), '23');

Horde::addScriptFile('prototype.js', 'horde', true);
Horde::addScriptFile('tooltip.js', 'horde', true);

require WATSON_TEMPLATES . '/common-header.inc';
require WATSON_TEMPLATES . '/menu.inc';
require WATSON_TEMPLATES . '/panel.inc';

//Get schedules for each channel.
foreach ($channels as $channel) {
    $date = date('Y-m-d');
    $schedule = Watson::factory($channel, $date);
    $result[$channel] = $schedule->process();
}

$times = array();
$_time = Util::getFormData('time', (date('H') - 1));

if ($_time > 23) {
    $_time = '23';
} elseif ($_time < 5) {
    $_time = '5';
}

$times[0] = date('H:i', mktime ($_time, 0, 0, date('m'), date('d'), date('Y')));
$times[1] = date('H:i', strtotime($times[0]) + 3600);
$times[2] = date('H:i', strtotime($times[1]) + 3600);

$num = count($times);

$print = '<table style="width:100%" id="timetable">';
$print .= '<tr><td></td><td style="width:30%">|'.$times[0].'</td><td style="width:30%">|'.$times[1].'</td><td style="width:30%">|'.$times[2].'</td></tr>';

for ($i = 0; $i < $numChannels; $i++) {

    $print .= '<tr>';
    $print .= '<td class="channel">' . $channels[$i] . '</td><td colspan='.$num.'>';

    $j=0;
    $temp = array();
    foreach ($result[$channels[$i]] as $time => $title) {
        if ($time != 'channel' && $time !='date' && $time !='forecast' && $time !='description') {
            $temp[$j][$time] = $result[$channels[$i]][$time];
            $j++;
        }
    }

    $last = key($temp[count($temp) - 1]);
    $temp[][$last] = ''; 
    $z = true;
    $timeSFlag = true;
    $timeEFlag = true;
    $widthA = 100;

    for ($j=1; $j<count($temp); $j++) {
        $start = key($temp[$j-1]);
        $end = strtotime(key($temp[$j]));
        $title = ucfirst(strtolower($temp[$j-1][$start]));
        $start = strtotime($start);

        if ($start > strtotime('12:00')) {
            $timeSFlag = false;
        }

        if ($end > strtotime('12:00')) {
            $timeEFlag = false;
        }

        if ($timeSFlag == false && $start < strtotime('6:00')) {
            $start = $start + 3600 * 24;
        }

        if ($timeEFlag == false && $end < strtotime('6:00')) {
            $end = $end + 3600 * 24;
        }

        $durationMin = ($end - $start) / 60;
        $_timeS = strtotime($times[0]);
        $_timeE = strtotime($times[0]) + 3 * 3600;

        if ($j % 2 == 0) {
            $colorClass = 'c1';
        } else {
            $colorClass = 'c2';
        }

        if ($end > $_timeS && $start < $_timeE) {

            if ($start < $_timeS) {
                $durationMin = ($end - $_timeS) / 60;
            }

            if ($end > $_timeE) {
                $durationMin = ($_timeE - $start) / 60;
            }

            if ($durationMin == 0) {
                $durationMin = ($_timeE - $start) / 60;
            }

            $width = round($durationMin * 100 / 180);
            $delay = floor(($start - $_timeS) / 60 * 100 / 180);

            if ($delay > 0 && $z == true) {
                $widthA = $widthA - $delay;
            }

            if ($delay > 0 && $z == true) {  
                $print .= '<div style="width:' . $delay .'%; float: left; height:10px;"></div>';
                $z = false;
            }

            $widthA = $widthA - $width;

            if ($widthA < 0) {
                $width = $width + $widthA; $widthA = 0;
            }

            $print .= '<div class="' . $colorClass . '" style="width:' . $width .'%;">';

            if ($width > 2) {
                $words = explode(' ', $title);
                $title2 = '';
                foreach ($words as $key => $word) {
                    $widthBesede = strlen($word);
                    if ($widthBesede > $width || intval($key) > 5) {
                        $title2 .= ' ...';
                        break;
                    } else {
                        $title2 .= ' ' . $word;
                    }
                }

                $title .= "\n" . _("Start: ") . date($GLOBALS['prefs']->getValue('twentyFour') ? 'G:i' : 'g:ia', $start);
                $title .= "\n" . _("End: ") .  date($GLOBALS['prefs']->getValue('twentyFour') ? 'G:i' : 'g:ia', $end);
                $print .= Horde::linkTooltip('javascript:void(0)', '', 'tool', '', '', $title, '', array()) . $title2 .'</a>';
            } else {
                $print .= ' ';
            }

            $print .= '</div>';
            $z = false;
        }
    }

    if ($widthA > 0) {
        if ($j % 2 == 0) {
            $colorClass = 'c1';
        } else {
            $colorClass = 'c2';
        }
        $print .= '<div class="' . $colorClass . '" style="width:' . $widthA .'%;">';
        if ($widthA == 100) {
            $print .= _("Timeline for this channel/day does not exist.");
        }
        $print .= '</div>';
    }

    $print .= '</td></tr>';
}

$print .= '</table>';

echo $tabs->render();
echo $print;

require $registry->get('templates', 'horde') . '/common-footer.inc';